@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,7 @@ class AutoCorrectionTreeWidget : public QTreeWidget
     Q_OBJECT
 public:
     explicit AutoCorrectionTreeWidget(QWidget *parent = nullptr);
-    ~AutoCorrectionTreeWidget();
+    ~AutoCorrectionTreeWidget() override;
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
