@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -30,7 +30,7 @@ public:
     ~NetworkManager();
     static NetworkManager *self();
 
-    QNetworkConfigurationManager *networkConfigureManager() const;
+    Q_REQUIRED_RESULT QNetworkConfigurationManager *networkConfigureManager() const;
 
 private:
     QNetworkConfigurationManager *mNetworkConfigureManager = nullptr;
